//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/Detector/Detector2D.h
//! @brief     Defines class Detector2D.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_DEVICE_DETECTOR_DETECTOR2D_H
#define BORNAGAIN_DEVICE_DETECTOR_DETECTOR2D_H

#include "Device/Detector/IDetector.h"

class Pixel;

class Detector2D : public IDetector {
public:
    Detector2D(double phi_span, double alpha_span, size_t n_phi, size_t n_alpha, double phi_center,
               double alpha_center);

    ~Detector2D() override = default;

    Detector2D* clone() const override;
    std::string className() const override { return "Detector2D"; }

    //! Creates an Pixel for the given Datafield object and index
    Pixel* createPixel(size_t index) const override;

    //! Returns index of pixel that contains the specular wavevector.
    //! If no pixel contains this specular wavevector, the number of pixels is
    //! returned. This corresponds to an overflow index.
    size_t indexOfSpecular(const Beam& beam) const override;
};

#endif // BORNAGAIN_DEVICE_DETECTOR_DETECTOR2D_H
