//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Detector/DetectorItem.h
//! @brief     Defines class DetectorItem.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DETECTOR_DETECTORITEM_H
#define BORNAGAIN_GUI_MODEL_DETECTOR_DETECTORITEM_H

#include "GUI/Model/Descriptor/PolyItem.h"
#include "GUI/Model/Descriptor/SpanProperty.h"
#include "GUI/Model/Detector/ResolutionFunctionItemCatalog.h"

class Beam;
class IDetector;
class IResolutionFunction2D;
class MasksSet;
class ResolutionFunctionItem;

class DetectorItem {
public:
    DetectorItem();
    ~DetectorItem();

    std::unique_ptr<IDetector> createDetector() const;

    void setMasks(MasksSet* item);

    PolyItem<ResolutionFunctionItemCatalog>& resolutionFunctionSelection()
    {
        return m_resolution_function;
    }

    template <typename T> T* setResolutionFunctionType();

    void writeTo(QXmlStreamWriter* w) const;
    void readFrom(QXmlStreamReader* r);

    SpanProperty& phiAxis() { return m_phi_axis; }
    const SpanProperty& phiAxis() const { return m_phi_axis; }

    SpanProperty& alphaAxis() { return m_alpha_axis; }
    const SpanProperty& alphaAxis() const { return m_alpha_axis; }

    bool expandResolutionFunc = true;

private:
    std::unique_ptr<IResolutionFunction2D> createResolutionFunction() const;

    SpanProperty m_phi_axis;
    SpanProperty m_alpha_axis;

    PolyItem<ResolutionFunctionItemCatalog> m_resolution_function;

    std::unique_ptr<MasksSet> m_masks;
    std::unique_ptr<MasksSet> m_prjns; //!< projections
};

template <typename T> T* DetectorItem::setResolutionFunctionType()
{
    m_resolution_function.createCertainItem<T>();
    return dynamic_cast<T*>(m_resolution_function.certainItem());
}

#endif // BORNAGAIN_GUI_MODEL_DETECTOR_DETECTORITEM_H
