//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Mask/MasksSet.cpp
//! @brief     Implements class MasksSet.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Mask/MasksSet.h"
#include "GUI/Model/Descriptor/PolyItem.h"
#include "GUI/Model/Mask/MasksCatalog.h"
#include "GUI/Model/Util/UtilXML.h"
#include <QRegularExpression>

namespace {
namespace Tag {

const QString Mask("Mask");

} // namespace Tag
} // namespace


MasksSet::MasksSet() = default;
MasksSet::~MasksSet() = default;

RegionOfInterestItem* MasksSet::regionOfInterestItem() const
{
    for (auto* t : *this)
        if (auto* roi = dynamic_cast<RegionOfInterestItem*>(t))
            return roi;

    return nullptr;
}

void MasksSet::writeTo(QXmlStreamWriter* w) const
{
    XML::writeAttribute(w, XML::Attrib::version, uint(1));

    for (const MaskItem* t : *this) {
        w->writeStartElement(Tag::Mask);
        PolyItem<MasksCatalog>::writeItemTo(t, w);
        w->writeEndElement();
    }
}

void MasksSet::readFrom(QXmlStreamReader* r)
{
    clear();

    const uint version = XML::readUInt(r, XML::Attrib::version);
    Q_UNUSED(version)

    while (r->readNextStartElement()) {
        QString tag = r->name().toString();

        if (tag == Tag::Mask) {
            add_item(PolyItem<MasksCatalog>().readItemFrom(r));
            XML::gotoEndElementOfTag(r, tag);

        } else
            r->skipCurrentElement();
    }
}
