//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/SamplesSet.cpp
//! @brief     Implements class SamplesSet.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Sample/SamplesSet.h"
#include "GUI/Model/Util/Backup.h"
#include "GUI/Model/Util/UtilXML.h"

namespace {
namespace Tag {

const QString Sample("Sample");
const QString CurrentIndex("CurrentIndex");

} // namespace Tag
} // namespace

SamplesSet::SamplesSet() = default;
SamplesSet::~SamplesSet() = default;

void SamplesSet::writeTo(QXmlStreamWriter* w) const
{
    XML::writeAttribute(w, XML::Attrib::version, uint(1));

    // samples
    for (const auto* t : *this) {
        w->writeStartElement(Tag::Sample);
        t->writeTo(w);
        w->writeEndElement();
    }

    // selected index
    w->writeStartElement(Tag::CurrentIndex);
    XML::writeAttribute(w, XML::Attrib::value, currentIndex());
    w->writeEndElement();
}

void SamplesSet::readFrom(QXmlStreamReader* r)
{
    clear();

    const uint version = XML::readUInt(r, XML::Attrib::version);
    Q_UNUSED(version)

    while (r->readNextStartElement()) {
        QString tag = r->name().toString();

        // sample
        if (tag == Tag::Sample) {
            auto* t = new SampleItem;
            t->readFrom(r);
            add_item(t);
            XML::gotoEndElementOfTag(r, tag);

            // selected index
        } else if (tag == Tag::CurrentIndex) {
            size_t i = XML::readSize(r, XML::Attrib::value);
            setCurrentIndex(i);
            XML::gotoEndElementOfTag(r, tag);

        } else
            r->skipCurrentElement();
    }
}
