//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Overlay/RectangleOverlay.h
//! @brief     Defines class RectangleOverlay.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_OVERLAY_RECTANGLEOVERLAY_H
#define BORNAGAIN_GUI_VIEW_OVERLAY_RECTANGLEOVERLAY_H

#include "GUI/View/Overlay/IRectangularOverlay.h"

class RectangleItem;

//! This is a View of rectangular mask (represented by RectangleItem) on GraphicsScene.
//! Given view follows standard QGraphicsScene notations: (x,y) is top left corner.

class RectangleOverlay : public IRectangularOverlay {
    Q_OBJECT
public:
    explicit RectangleOverlay(RectangleItem* item, ColorMap* plot);

    QPainterPath shape() const override;
    OverlayItem* parameterizedItem() const override;

private slots:
    void onChangedX() override;
    void onChangedY() override;
    void onPropertyChange() override;

private:
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event) override;

    void update_position() override;
    QRectF mask_rectangle() override;
    qreal width() const override;
    qreal height() const override;

    RectangleItem* m_item;
};

#endif // BORNAGAIN_GUI_VIEW_OVERLAY_RECTANGLEOVERLAY_H
