//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Overlay/SizeHandleElement.h
//! @brief     Defines class SizeHandleElement.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_OVERLAY_SIZEHANDLEELEMENT_H
#define BORNAGAIN_GUI_VIEW_OVERLAY_SIZEHANDLEELEMENT_H

#include <QGraphicsObject>

//! Size handle on top of RectangleOverlay represented as small circle or small rectangle.
//! Placed either in corners on in the middle of the edge.

class SizeHandleElement : public QGraphicsObject {
    Q_OBJECT
public:
    enum EHandleLocation {
        NONE,
        TOPLEFT,
        TOPMIDDLE,
        TOPRIGHT,
        MIDDLELEFT,
        MIDDLERIGHT,
        BOTTOMLEFT,
        BOTTOMMIDLE,
        BOTTOMRIGHT,
    };

    enum EHandleType { RESIZE, RESIZE_WIDTH, RESIZE_HEIGHT };

    SizeHandleElement(EHandleLocation pointType, QGraphicsObject* parent = nullptr);

    void updateHandleElementPosition(const QRectF& rect);

    QRectF boundingRect() const override;

    EHandleLocation getHandleLocation() const { return m_handle_location; }
    EHandleLocation getOppositeHandleLocation() const;
    EHandleType getHandleType() const { return m_handle_type; }

public slots:
    virtual void update_view();

signals:
    void resize_request(bool going_to_resize);

private:
    void paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event) override;

    EHandleLocation m_handle_location;
    EHandleType m_handle_type;
};

#endif // BORNAGAIN_GUI_VIEW_OVERLAY_SIZEHANDLEELEMENT_H
