//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Sample/LayerEditorUtil.h
//! @brief     Defines class GUI::Util::Layer.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SAMPLE_LAYEREDITORUTIL_H
#define BORNAGAIN_GUI_VIEW_SAMPLE_LAYEREDITORUTIL_H

#include "GUI/Model/Descriptor/DoubleProperty.h"
#include "GUI/Model/Sample/FormfactorsCatalog.h"
#include "GUI/Model/Sample/ParticlesCatalog.h"
#include <QGridLayout>
#include <QLabel>
#include <QPushButton>
#include <functional>

class DoubleSpinBox;
class FormFactorItem;
class ItemWithParticles;
class Profile1DItem;
class Profile2DItem;
class RotationItem;
class RoughnessItem;
class SampleEditorController;
class VectorProperty;

//! Utility functions to support layer oriented sample editor
namespace GUI::Util::Layer {

//! Create DoubleSpinBoxes for the DoubleProperties and connect them to
//! SampleEditorController::setDouble()
void addMultiPropertyToGrid(QGridLayout* m_grid_layout, int firstCol,
                            const DoubleProperties& valueProperties, SampleEditorController* ec,
                            bool vertically, bool addSpacer);

//! Create DoubleSpinBoxes for the DoubleProperties and connect them to the given setNewValue()
void addMultiPropertyToGrid(QGridLayout* m_grid_layout, int firstCol,
                            const DoubleProperties& valueProperties,
                            std::function<void(double, DoubleProperty&)> setNewValue,
                            bool vertically, bool addSpacer);

void addMultiPropertyToGrid(QGridLayout* m_grid_layout, int firstCol,
                            const DoubleProperties& valueProperties, SampleEditorController* ec,
                            bool addSpacer);

QWidget* createWidgetForItemWithParticles(QWidget* parentWidget,
                                          ItemWithParticles* itemWithParticles, bool allowAbundance,
                                          SampleEditorController* ec, bool allowRemove = true);

QPushButton*
createAddParticleButton(QWidget* parentWidget,
                        std::function<void(FormfactorsCatalog::Type t)> slotAddFormFactor,
                        std::function<void(ParticlesCatalog::Type t)> slotAddParticle);

QVector<QColor> predefinedLayerColors();

} // namespace GUI::Util::Layer

#endif // BORNAGAIN_GUI_VIEW_SAMPLE_LAYEREDITORUTIL_H
